import request from '@/utils/request'

// 初始化 未编制 零件号111
export function getPartnames1() {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '车间生产管理工艺_零件工艺计划_编制定额_查询数据'
    }
  })
}
// 初始化 已编制 零件号
export function getPartnames2(person) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '车间生产管理工艺_零件工艺计划_查询已完成定额制定零件',
      param: '定额人员编号=' + person + '=int'
    }
  })
}

// 人员111
export function getPerson() {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '人事档案管理_人员_部门与人员_查询数据_根据部门编号',
      param: '考核部门编号=20'
    }
  })
}
// 零件详细信息111
export function detailInfo(serialNum) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '车间生产管理工艺_零件工艺计划_查已投产零件信息',
      param: '工艺计划流水号=' + serialNum + '=int'
    }
  })
}

// 主界面选择零件号查主表
export function mainTable(num) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '车间生产管理工艺_零件工序_查询数据_根据工艺计划流水号_零件定额制定',
      param: '工艺计划流水号=' + num + '=int'
    }
  })
}
export function mainTable1(num) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '车间生产管理工艺_零件工序_查询数据_根据工艺计划流水号',
      param: '工艺计划流水号=' + num + '=int'
    }
  })
}

// 已编制保存
export function TableAddLi(a, b, c, num0, num1) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '车间生产管理工艺_零件工序_增加数据_修改数据',
      param: '单件定额工时=' + a + '=string&准结定额工时=' + b + '=string&零件图号=' + c + '=string&工序流水号=' + num0 + '=int&工艺计划流水号=' + num1 + '=int'
    }
  })
}
// 未编制保存
export function TableAddLi1(a, b) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '车间生产管理工艺_定额任务分配_保存数据',
      param: '工艺计划流水号=' + a + '=string&人员编号=' + b + '=string'
    }
  })
}
